#ifndef REPORTGEN_H_
#define REPORTGEN_H_

#include "maintenance.h"

class reportgen : public maintenance
{
public:
	reportgen(int fd, bool bVerbose=false);
	virtual void Run(const MYSTD::string &);
protected:
	virtual void GenReport(const MYSTD::string & cmd);
	bool m_bVerbose;
};

#endif /*REPORTGEN_H_*/
